{#- Template for object labels.

Labels are additional information that can be displayed alongside an object.


Context:
    labels (list): The list of labels to render.
    config (dict): The configuration options.
-#}

{% if config.show_labels and labels %}
  <span class="doc doc-labels">
    {% for label in labels %}
      <small class="doc doc-label doc-label-{{ label }}"><code>{{ label }}</code></small>
    {% endfor %}
  </span>
{% endif %}
