{#- Template for pou summary


Context:
  context plcproj
-#}


{% if config.summary_section_style == "table" %}
  {% block table_style scoped %}
    {#- Block for the `table` section style. -#}
    <p><span class="doc-section-title">Function Blocks</span></p>
    <table>
      <thead>
        <tr>
          <th>Name</th>
          <th>Description</th>
        </tr>
      </thead>
      <tbody>
        {% for pou in context.pous %}
          <tr class="doc-section-item">
            <td><code><autoref identifier="{{ pou.get_identifier() }}" optional hover>{{ pou.name }}</autoref></code></td>
            <td>
            {% if pou.documentation and pou.documentation.details %}
              <div class="doc-md-description">
                {{ pou.documentation.details|convert_markdown(heading_level, html_id, autoref_hook=autoref_hook) }}
              </div>
              {% endif %}
            </td>
          </tr>
        {% endfor %}
      </tbody>
    </table>
  {% endblock table_style %}
{% elif config.summary_section_style == "list" %}
  {% block list_style scoped %}
    {#- Block for the `list` section style. -#}
    <p><span class="doc-section-title">Function Blocks</span></p>
    <ul>
      {% for pou in context.pous %}
        <li class="doc-section-item field-body">
          <b><code><autoref identifier="{{ pou.get_identifier() }}" optional hover>{{ pou.name }}</autoref></code></b>
          {% if pou.documentation and pou.documentation.details %}
          –
          <div class="doc-md-description">
            {{ pou.documentation.details|convert_markdown(heading_level, html_id, autoref_hook=autoref_hook) }}
          </div>
          {% endif %}
        </li>
      {% endfor %}
    </ul>
  {% endblock list_style %}
{% endif %}