{#- Template for auto-summaries.


context: context = Pou, itf, plcproj
 -#}




{% if config.summary.itfs and context.itfs %}
  {% include "summary/itfs.html.jinja" %}
{% endif %}


{% if config.summary.pous and context.pous %}
  {% include "summary/pous.html.jinja"  %}
{% endif %}


{% if config.summary.duts and context.duts %}
  {% include "summary/duts.html.jinja" %}
{% endif %}


{% if config.summary.gvls and context.gvls %}
  {% include "summary/gvls.html.jinja" %}
{% endif %}


{% if config.summary.methods and context.methods %}
  {% include "summary/methods.html.jinja" %}
{% endif %}


{% if config.summary.properties and context.properties %}
  {% include "summary/properties.html.jinja" %}
{% endif %}

{% if config.summary.variables and context.variables %}
  {% include "summary/variables.html.jinja" %}
{% endif %}
